# opencc-js [![](https://badge.fury.io/js/opencc-js.svg)](https://www.npmjs.com/package/opencc-js) [![](https://github.com/nk2028/opencc-js/workflows/Test/badge.svg)](https://github.com/nk2028/opencc-js/actions?query=workflow%3ATest) [![](https://data.jsdelivr.com/v1/package/npm/opencc-js/badge)](https://www.jsdelivr.com/package/npm/opencc-js)

The JavaScript version of Open Chinese Convert (OpenCC)

[繁體版](README-zh-TW.md) - [简体版](README-zh-CN.md)

## Import

**Import opencc-js in HTML**

Load the following four `script` tags in sequence:

```html
<!-- The following one is required -->
<script src="https://cdn.jsdelivr.net/npm/opencc-js@1.0.1/data.min.js"></script>
<!-- The following one can be removed for speed if you do not need to convert from Simplified Chinese to Traditional Chinese -->
<script src="https://cdn.jsdelivr.net/npm/opencc-js@1.0.1/data.cn2t.min.js"></script>
<!-- The following one can be removed for speed if you do not need to convert from Traditional Chinese to Simplified Chinese -->
<script src="https://cdn.jsdelivr.net/npm/opencc-js@1.0.1/data.t2cn.min.js"></script>
<!-- The following one is required -->
<script src="https://cdn.jsdelivr.net/npm/opencc-js@1.0.1/bundle-browser.min.js"></script>
```

**Import opencc-js in Node.js**

```sh
npm install opencc-js
```

```javascript
const OpenCC = require('opencc-js');
```

## Usage

**Basic usage**

```javascript
// Convert Traditional Chinese (Hong Kong) to Simplified Chinese (Mainland China)
const converter = OpenCC.Converter({ from: 'hk', to: 'cn' });
console.log(converter('漢字，簡體字')); // output: 汉字，简体字
```

- `cn`: Simplified Chinese (Mainland China)
- `tw`: Traditional Chinese (Taiwan)
- `twp`: Traditional Chinese (Taiwan, with phrase conversion)
- `hk`: Traditional Chinese (Hong Kong)
- `jp`: Japanese Shinjitai
- `t`: Traditional Chinese (OpenCC standard. Do not use unless you know what you are doing)

**Custom Converter**

```javascript
const converter = OpenCC.CustomConverter([
  ['香蕉', 'banana'],
  ['蘋果', 'apple'],
  ['梨', 'pear'],
]);
console.log(converter('香蕉 蘋果 梨')); // output: banana apple pear
```

**DOM operations**

```javascript
// Convert Traditional Chinese (Hong Kong) to Simplified Chinese (Mainland China)
const converter = OpenCC.Converter({ from: 'hk', to: 'cn' });
// Set the conversion starting point to the root node, i.e. convert the whole page
const rootNode = document.documentElement;
// Convert all zh-HK tags to zh-CN tags
const HTMLConvertHandler = OpenCC.HTMLConverter(converter, rootNode, 'zh-HK', 'zh-CN');
// Start conversion
HTMLConvertHandler.convert();
// Restore
HTMLConvertHandler.restore();
```

All the tags which contains `ignore-opencc` in the class list will not be converted (including all sub-nodes of the tags).
